Skip to contents

Visualize the number of subclones on the differentiation tree

Usage

plot_differentiation_tree(
  x,
  edges = differentiation_tree(),
  highlight = c(),
  by_timepoint = F,
  clonal = T,
  wrap = T,
  timepoints = c(),
  min_abundance = 0
)

Arguments

x

add

edges

add

highlight

add

wrap

add

single_tree

add

Value

A ggplot object showing the identified subclones in the hematopoietic tree.